import configparser

import pytest
import solary

def test_appmag2irr():

    config = configparser.ConfigParser()
    config.read('_config/constants.ini')
    appmag_irr_i0 = float(config['photometry']['appmag_irr_i0'])

    irradiance1 = solary.general.photometry.appmag2irr(app_mag=0)
    assert pytest.approx(irradiance1) == appmag_irr_i0

    irradiance2 = solary.general.photometry.appmag2irr(app_mag=-5)
    assert pytest.approx(irradiance2) == appmag_irr_i0 * 100.0

    irradiance3 = solary.general.photometry.appmag2irr(app_mag=1)
    assert pytest.approx(irradiance3) == 1.0024422165005002e-08



"""
TBD

"""

# Import standard modules
import math

def ast_size(albedo, abs_mag):
    """
    TBD

    Parameters
    ----------
    albedo : TYPE
        DESCRIPTION.
    abs_mag : TYPE
        DESCRIPTION.

    Returns
    -------
    radius : TYPE
        DESCRIPTION.

    References
    ----------
    [1] Chesley, Steven R.; Chodas, Paul W.; Milani, Andrea; Valsecchi, Giovanni B.; Yeomans,
        Donald K. (October 2002). Quantifying the Risk Posed by Potential Earth Impacts. Icarus.
        159 (2): 425
    [2] https://cneos.jpl.nasa.gov/tools/ast_size_est.html
    [3] http://www.physics.sfasu.edu/astro/asteroids/sizemagnitude.html

    """

    # Compute the diameter in km
    diameter = (1329.0 / math.sqrt(albedo)) * 10.0 ** (-0.2 * abs_mag)

    # Conver the diameter to m
    diameter *= 1000.0

    # Convert the diameter to radius
    radius = diameter / 2.0

    return radius



import pytest
import solary

def test_ast_size():

    ast_radius1 = solary.asteroid.physp.ast_size(albedo=0.05, abs_mag=10.0)
    assert pytest.approx(ast_radius1) == 29717.34

    ast_radius2 = solary.asteroid.physp.ast_size(albedo=0.3, abs_mag=20.0)
    assert pytest.approx(ast_radius2) == 121.32055
    
    ast_radius3 = solary.asteroid.physp.ast_size(albedo=0.15, abs_mag=26.0)
    assert pytest.approx(ast_radius3) == 10.825535


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="solary",
    version="0.1",
    author="Thomas Albin",
    description="TBD",
    long_description=long_description,
    url="https://github.com/ThomasAlbin/SolarY",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
    python_requires='>=3.8',
)



"""
TBD
"""

# Import standard modules
import configparser
import math

def appmag2irr(app_mag):
    """
    Convert the apparent magnitude to the corresponding irradiance given in
    W/m^2.

    Parameters
    ----------
    app_mag : int or float
        Apparent bolometric magnitude given in mag.

    Returns
    -------
    irradiance : float
        Irradiance given in W/m^2.

    """

    # Load the configuration file that contains the zero point bolometric
    # irradiance
    config = configparser.ConfigParser()
    config.read('_config/constants.ini')
    appmag_irr_i0 = float(config['photometry']['appmag_irr_i0'])

    # Convert apparent magnitude to irradiance
    irradiance = 10.0 ** (-0.4 * app_mag + math.log10(appmag_irr_i0))

    return irradiance
